@@ -2,7 +2,7 @@
 # PODNAME: Test::Rail::Parser
 
 package Test::Rail::Parser;
-$Test::Rail::Parser::VERSION = '0.044';
+$Test::Rail::Parser::VERSION = '0.046';
 use strict;
 use warnings;
 use utf8;
@@ -151,13 +151,11 @@ sub new {
         ( grep { $_ eq $c->{'name'} } @{ $tropts->{'configs'} } )
     } @$configz2create;
     if ( scalar(@$configz2create) && $tropts->{'config_group'} ) {
-        my $cgroup =
-          $tr->getConfigurationGroupByName( $tropts->{project_id},
+        my $cgroup = $tr->getConfigurationGroupByName( $tropts->{project_id},
             $tropts->{'config_group'} );
         unless ( ref($cgroup) eq 'HASH' ) {
             print "# Adding Configuration Group $tropts->{config_group}...\n";
-            $cgroup =
-              $tr->addConfigurationGroup( $tropts->{project_id},
+            $cgroup = $tr->addConfigurationGroup( $tropts->{project_id},
                 $tropts->{'config_group'} );
         }
         confess(
@@ -175,7 +173,7 @@ sub new {
     confess("Could not retrieve list of valid configurations for your project.")
       unless ( reftype($config_ids) || 'undef' ) eq 'ARRAY';
     my @bogus_configs = grep { !defined($_) } @$config_ids;
-    my $num_bogus = scalar(@bogus_configs);
+    my $num_bogus     = scalar(@bogus_configs);
     confess(
         "Detected $num_bogus bad config names passed.  Check available configurations for your project."
     ) if $num_bogus;
@@ -192,8 +190,7 @@ sub new {
           && ( !$tropts->{'testsuite_id'} );
         if ( $plan && !$plan->{'is_completed'} ) {
             $tropts->{'plan'} = $plan;
-            $run =
-              $tr->getChildRunByName( $plan, $tropts->{'run'},
+            $run = $tr->getChildRunByName( $plan, $tropts->{'run'},
                 $tropts->{'configs'} );    #Find plan filtered by configs
 
             if ( defined($run) && ( reftype($run) || 'undef' ) eq 'HASH' ) {
@@ -454,7 +451,7 @@ sub testCallback {
             $status      = $self->{'tr_opts'}->{'todo_pass'}->{'id'};
             $status_name = 'TODO PASS';
             $test_name =~ s/^(ok|not ok)\s[0-9]*\s//g;
-            $test_name =~ s/^# todo & skip //gi;    #handle todo_skip
+            $test_name =~ s/^# todo & skip //gi;         #handle todo_skip
             $test_name =~ s/# todo\s(.*)$//gi;
             $todo_reason = $test->explanation();
         }
@@ -464,7 +461,7 @@ sub testCallback {
             $status      = $self->{'tr_opts'}->{'todo_fail'}->{'id'};
             $status_name = 'TODO FAIL';
             $test_name =~ s/^(ok|not ok)\s[0-9]*\s//g;
-            $test_name =~ s/^# todo & skip //gi;    #handle todo_skip
+            $test_name =~ s/^# todo & skip //gi;         #handle todo_skip
             $test_name =~ s/# todo\s(.*)$//gi;
             $todo_reason = $test->explanation();
         }
@@ -748,7 +745,7 @@ Test::Rail::Parser - Upload your TAP results to TestRail
 
 =head1 VERSION
 
-version 0.044
+version 0.046
 
 =head1 DESCRIPTION
 
@@ -908,12 +905,12 @@ George S. Baugh <teodesian@cpan.org>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/teodesian/TestRail-Perl>
+The development version is on github at L<https://github.com/teodesian/TestRail-Perl>
 and may be cloned from L<git://github.com/teodesian/TestRail-Perl.git>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by George S. Baugh.
+This software is copyright (c) 2020 by George S. Baugh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
