@@ -2,7 +2,7 @@
 # ABSTRACT: Find runs and tests according to user specifications.
 
 package TestRail::Utils::Find;
-$TestRail::Utils::Find::VERSION = '0.044';
+$TestRail::Utils::Find::VERSION = '0.046';
 use strict;
 use warnings;
 
@@ -44,7 +44,7 @@ sub findRuns {
     $runs = $tr->getRuns( $project->{'id'} )
       if ( !$opts->{'configs'} )
       ;    # If configs are passed, global runs are not in consideration.
-    $plans = $tr->getPlans( $project->{'id'} );
+    $plans  = $tr->getPlans( $project->{'id'} );
     @$plans = map { $tr->getPlanByID( $_->{'id'} ) } @$plans;
     foreach my $plan (@$plans) {
         $cruns = $tr->getChildRuns($plan);
@@ -363,9 +363,8 @@ sub getResults {
                     next if !$run->{id};
 
                     #Translate config ids to names, also remove any gone configs
-                    my @run_configs =
-                      grep { defined $_ }
-                      map  { $config_map{$_} } @{ $run->{config_ids} };
+                    my @run_configs = grep { defined $_ }
+                      map { $config_map{$_} } @{ $run->{config_ids} };
                     next
                       if scalar( @{ $opts->{runs} } )
                       && !( grep { $_ eq $run->{'name'} }
@@ -376,7 +375,7 @@ sub getResults {
                             my $cname = basename($_);
                             my $c = $tr->getTestByName( $run->{id}, $cname );
                             $c->{config_ids} = \@run_configs;
-                            $c->{name} = $cname if $c;
+                            $c->{name}       = $cname if $c;
                             $c
                         } @csz;
                         next unless scalar(@csz);
@@ -403,8 +402,7 @@ sub getResults {
                         next unless ref $c eq 'HASH';
 
                         $res->{$case} //= [];
-                        $c->{results} =
-                          $tr->getTestResults( $c->{'id'},
+                        $c->{results} = $tr->getTestResults( $c->{'id'},
                             $tr->{'global_limit'}, 0 );
                         $c->{config_ids} = \@run_configs;
                         $c = _filterResults( $opts, $c );
@@ -480,7 +478,7 @@ TestRail::Utils::Find - Find runs and tests according to user specifications.
 
 =head1 VERSION
 
-version 0.044
+version 0.046
 
 =head1 DESCRIPTION
 
@@ -489,7 +487,7 @@ version 0.044
 =head2 findRuns
 
 Find runs based on the options HASHREF provided.
-See the documentation for L<testrail-runs>, as the long argument names there correspond to hash keys.
+See the documentation for testrail-runs, as the long argument names there correspond to hash keys.
 
 The primary routine of testrail-runs.
 
@@ -617,12 +615,12 @@ George S. Baugh <teodesian@cpan.org>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/teodesian/TestRail-Perl>
+The development version is on github at L<https://github.com/teodesian/TestRail-Perl>
 and may be cloned from L<git://github.com/teodesian/TestRail-Perl.git>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by George S. Baugh.
+This software is copyright (c) 2020 by George S. Baugh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
